@@ -50,8 +50,6 @@ class ConvertXmindToExcel:
                 for file_name in file_list:
                     if not file_name.endswith('.xmind'):
                         continue
-                    print(os.path.join(path, file_name))
-                    print(os.path.join(excel_path, file_name.replace('.xmind', '.xlsx')))
                     self.convert_single_file(os.path.join(path, file_name),
                                              os.path.join(excel_path, file_name.replace('.xmind', '.xlsx')),
                                              ignore_layer_number)
